build method

  1. @override
Widget build(
  1. BuildContext context
)
override

Describes the part of the user interface represented by this widget.

The framework calls this method when this widget is inserted into the tree in a given BuildContext and when the dependencies of this widget change (e.g., an InheritedWidget referenced by this widget changes). This method can potentially be called in every frame and should not have any side effects beyond building a widget.

The framework replaces the subtree below this widget with the widget returned by this method, either by updating the existing subtree or by removing the subtree and inflating a new subtree, depending on whether the widget returned by this method can update the root of the existing subtree, as determined by calling Widget.canUpdate.

Typically implementations return a newly created constellation of widgets that are configured with information from this widget's constructor and from the given BuildContext.

The given BuildContext contains information about the location in the tree at which this widget is being built. For example, the context provides the set of inherited widgets for this location in the tree. A given widget might be built with multiple different BuildContext arguments over time if the widget is moved around the tree or if the widget is inserted into the tree in multiple places at once.

The implementation of this method must only depend on:

If a widget's build method is to depend on anything else, use a StatefulWidget instead.

See also:

  • StatelessWidget, which contains the discussion on performance considerations.

Implementation

@override
Widget build(BuildContext context) {
  final columnSpacing = getColumnSpacing(context);

  final rowSpacing = getRowSpacing(context);

  final columnSizes = DesignGridColumnSizes.of(context);

  final columns = columnSizes.length;

  final sizedChildren = <Widget>[];

  var columnCounter = 0;

  for (final child in children) {
    final isChildBreak = child is DesignGridItemBreak;

    // ignore the break if we are at the start of the row
    if (columnCounter == 0 && isChildBreak) {
      continue;
    }

    var childColumns = isChildBreak ? columns - columnCounter : getItemColumns(context, child);

    // make sure the child columns don't overflow the total columns
    childColumns = childColumns.clamp(0, columns);

    // don't display children with "invisible" column-span
    if (childColumns <= 0) {
      continue;
    }

    // if the child columns would overflow the current row, start a new one by setting columnCounter to zero
    if (columnCounter + childColumns > columns) {
      columnCounter = 0;
    }

    double childSize = DesignGridCalculator.calculateChildSize(
      columnSizes: columnSizes,
      columnCounter: columnCounter,
      childColumns: childColumns,
      columnSpacing: columnSpacing,
    );

    columnCounter += childColumns;

    final childWidget = KeyedSubtree.wrap(
      buildChild(childColumns, childSize, child),
      children.indexOf(child),
    );

    sizedChildren.add(childWidget);
  }

  final effectiveAlignment = alignment ?? DesignGridDefaultRowAlignment.of(context);

  return SizedBox(
    width: double.infinity,
    child: Wrap(
      alignment: effectiveAlignment.toWrapAlignment(),
      spacing: columnSpacing,
      runSpacing: rowSpacing,
      children: sizedChildren,
    ),
  );
}