DesignGridRowAlignment enum

Inheritance
Available extensions

Values

start → const DesignGridRowAlignment

Place the objects as close to the start of the axis as possible.

If this value is used in a horizontal direction, a TextDirection must be available to determine if the start is the left or the right.

If this value is used in a vertical direction, a VerticalDirection must be available to determine if the start is the top or the bottom.

end → const DesignGridRowAlignment

Place the objects as close to the end of the axis as possible.

If this value is used in a horizontal direction, a TextDirection must be available to determine if the end is the left or the right.

If this value is used in a vertical direction, a VerticalDirection must be available to determine if the end is the top or the bottom.

center → const DesignGridRowAlignment

Place the objects as close to the middle of the axis as possible.

spaceBetween → const DesignGridRowAlignment

Place the free space evenly between the objects.

spaceAround → const DesignGridRowAlignment

Place the free space evenly between the objects as well as half of that space before and after the first and last objects.

spaceEvenly → const DesignGridRowAlignment

Place the free space evenly between the objects as well as before and after the first and last objects.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMainAxisAlignment() MainAxisAlignment
Returns the MainAxisAlignment that corresponds to this DesignGridRowAlignment.
toString() String
A string representation of this object.
inherited
toWrapAlignment() WrapAlignment
Returns the WrapAlignment that corresponds to this DesignGridRowAlignment.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DesignGridRowAlignment>
A constant List of the values in this enum, in order of their declaration.