MaterialDesignGrid class

Inheritance

Constructors

MaterialDesignGrid({Key? key, bool hasFullWindowWidth = false, DesignGridRowAlignment defaultRowAlignment = DesignGridRowAlignment.start, DesignGridLayoutType layoutType = DesignGridLayoutType.column, bool shrinkWrap = false, required List<MaterialDesignGridRow> children})
const

Properties

children List<MaterialDesignGridRow>
final
defaultRowAlignment DesignGridRowAlignment
final
hasFullWindowWidth bool
Set to true if this MaterialDesignGrid widget is top level and has the full horizontal space of the window/application. This is good for performance, by default this is false and uses LayoutBuilder to estimate the available horizontal space.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
layoutType → DesignGridLayoutType
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shrinkWrap bool
Whether to shrink wrap the grid or not. If true, the grid will be as small as possible. This is bad for performance, so use it only if necessary. Also only works with DesignGridLayoutType.listView
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited