MaterialDesignGridBreakpoints class
The default implementation according to the Material Design Layout. If you want to change any values, create a class that extends this one and override the functions you want to change.
Constructors
- MaterialDesignGridBreakpoints()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getBodyWidth(
double width) → double? -
getColumns(
double width) → int -
getMargin(
double width) → double? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited