MaterialDesignGridThemeData class
Constructors
- MaterialDesignGridThemeData({MaterialDesignGridBreakpoints breakpoints = const MaterialDesignGridBreakpoints(), double columnSpacing = 16.0, double rowSpacing = 16.0})
-
const
Properties
- breakpoints → MaterialDesignGridBreakpoints
-
The breakpoints for the Material Design grid.
final
- columnSpacing → double
-
The spacing between columns.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- rowSpacing → double
-
The spacing between rows.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
covariant MaterialDesignGridThemeData other) → bool -
The equality operator.
override