ResponsiveDesignGridBreakpoints class

Constructors

ResponsiveDesignGridBreakpoints({double small = 375, double medium = 768, double large = 1280, double extraLarge = 1920})
const

Properties

extraLarge double
final
hashCode int
The hash code for this object.
no setterinherited
large double
final
medium double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
small double
final

Methods

getDisplaySize(double width) ResponsiveDesignGridDisplaySize
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited