breakpoints property
If you want to override the default breakpoints, you can pass them in here.
Implementation
final ResponsiveDesignGridBreakpoints breakpoints;
If you want to override the default breakpoints, you can pass them in here.
final ResponsiveDesignGridBreakpoints breakpoints;