columns property
Specify the number of columns this child should occupy for each breakpoint.
Implementation
final ResponsiveDesignGridColumns columns;
Specify the number of columns this child should occupy for each breakpoint.
final ResponsiveDesignGridColumns columns;