ResponsiveDesignGridColumns class
Defines the number of columns a ResponsiveDesignGridItem should take up for each ResponsiveDesignGridDisplaySize. Values are inherited from small to extraLarge. Small is always required and will be used for all other breakpoints that are not defined. Example:
ResponsiveDesignGridColumns(
small: 4,
large: 2,
)
The number of columns will be 4 on small and since medium isn't set, it will be taken from small. On large the number of columns will be 2 and on extra large too, since the closest next-smaller breakpoint large is defined with 2 columns
Constructors
- ResponsiveDesignGridColumns({required int small, int? medium, int? large, int? extraLarge})
-
const
Properties
Methods
-
getColumns(
ResponsiveDesignGridDisplaySize displaySize) → int -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited