ResponsiveDesignGridThemeData class
Properties
-
columns
→ int
-
The number of columns in the grid.
final
-
columnSpacing
→ double
-
The spacing between columns.
final
-
gridPadding
→ double
-
The padding on the left and right of
DesignGrid widgets. Nested DesignGrid widgets will not use this padding by default.
final
-
hashCode
→ int
-
The hash code for this object.
no setteroverride
-
rowSpacing
→ double
-
The spacing between rows.
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited